@@ -23,7 +23,7 @@
 #' @export
 ncombinations <- function(x = NULL, k = n, n = NULL, v = NULL, freq = NULL, replace = FALSE,
                           bigz = FALSE) {
-    .Call("ncombinations", PACKAGE = "arrangements", x, k, n, v, freq, replace, bigz)
+    .Call(C_ncombinations, x, k, n, v, freq, replace, bigz)
 }
 
 
@@ -76,7 +76,7 @@ ncombinations <- function(x = NULL, k = n, n = NULL, v = NULL, freq = NULL, repl
 #' @export
 combinations <- function(x = NULL, k = n, n = NULL, v = NULL, freq = NULL, replace = FALSE,
                          layout = NULL, nitem = -1L, skip = NULL, index = NULL, nsample = NULL, drop = NULL) {
-    .Call("get_combinations", PACKAGE = "arrangements",
+    .Call(C_collect_combinations,
           x, k, n, v, freq, replace, layout, nitem, index, nsample, NULL, skip, drop)
 }
 
@@ -126,7 +126,7 @@ Combinations <- R6::R6Class(
                 out <- NULL
                 self$reset()
             } else {
-                out <- .Call("get_combinations", PACKAGE = "arrangements",
+                out <- .Call(C_collect_combinations,
                              NULL, self$k, self$n, self$v, self$freq, self$replace, layout,
                              d, NULL, NULL, private$state, self$skip, drop)
                 is.null(out) && self$reset()
@@ -167,7 +167,7 @@ icombinations <- function(x, k = n, n = NULL, v = NULL, freq = NULL, replace = F
         n <- validate_n_value(n, v, freq, replace)
     } else {
         if (length(x) == 1 && is.numeric(x)) {
-            n <- validate_n_value(x, v, freq)
+            n <- validate_n_value(x, v, freq, replace)
         } else {
             v <- x
             n <- validate_n_value(n, v, freq, replace)
