@@ -4,17 +4,17 @@
 #include "combinations.h"
 #include "permutations.h"
 #include "partitions.h"
-#include "utils.h"
+
 
 static const R_CallMethodDef CallEntries[] = {
     {"ncombinations", (DL_FUNC) &ncombinations, 7},
-    {"get_combinations", (DL_FUNC) &get_combinations, 13},
+    {"collect_combinations", (DL_FUNC) &collect_combinations, 13},
 
     {"npermutations", (DL_FUNC) &npermutations, 7},
-    {"get_permutations", (DL_FUNC) &get_permutations, 13},
+    {"collect_permutations", (DL_FUNC) &collect_permutations, 13},
 
     {"npartitions", (DL_FUNC) &npartitions, 3},
-    {"get_partitions", (DL_FUNC) &get_partitions, 10},
+    {"collect_partitions", (DL_FUNC) &collect_partitions, 10},
 
     {NULL, NULL, 0}
 };
